Orange Canvas Core
==================

.. image:: https://travis-ci.org/biolab/orange-canvas-core.svg?branch=master
   :target: https://travis-ci.org/biolab/orange-canvas-core
   :alt: Travis CI Build Status

.. image:: https://ci.appveyor.com/api/projects/status/6kurw9dg0e3t285t?svg=true
   :target: https://ci.appveyor.com/project/biolab/orange-canvas-core
   :alt: Appveyor CI Build Status

.. image:: https://readthedocs.org/projects/orange-canvas-core/badge/?version=latest
   :target: https://orange-canvas-core.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

Orange Canvas Core is a framework for building graphical user
interfaces for editing workflows. It is a component used to build
the Orange Canvas (http://orange.biolab.si) data-mining application
(for which it was developed in the first place).


Installation
------------

Orange Canvas Core is pip installable (https://pip.pypa.io/), simply run::

    pip install orange-canvas-core

Or use the::

    pip install ./

to install from the sources.
